@@ -1,6 +1,7 @@
 import logging
 import socket
 import threading
+import time
 
 from web_framework_v2.parser import RequestParser
 
@@ -57,4 +58,7 @@ class HttpClient:
                 logger.debug(f"Finished building response object {response}")
                 response_data = response.data()
                 self.send(response_data)
+                self.socket.shutdown(socket.SHUT_WR)  # wait for fin
+                self.socket.recv(1)  # receive fin
+                time.sleep(0.01)  # timeout just in case
             self.close()
